Index of Section 1 Manual Pages
| Interix / SUA | type.1 | Interix / SUA |
type(1) type(1)
type
NAME
type - write a description of a command type
SYNOPSIS
type name ...
DESCRIPTION
The type(1) command reports on how each name would be interpreted if used
as a command name. For example, a name can be reported as a shell built-
in, a function, an alias, or a keyword; if name is a separate utility,
type(1) displays the path name.
DIAGNOSTICS
The type(1) utility exits with status 0 for success, and >0 if an error
occurred.
NOTES
This command is a shell built-in.
SEE ALSO
ksh(1)